@@ -1,6 +1,6 @@
 # The database to run the tests on. Having it empty means that the
 # environment variable MIMER_DATABASE controls the database to connect to.
-DBNAME = 'py23'
+DBNAME = ''
 
 # The test connects to SYSADM_USR and creates a subident that is used for all
 # the tests. After testing, the subident is dropped and everything goes away.
@@ -39,7 +39,6 @@ def setup():
             if de.message[0] != -12517:
                 pass
             else:
-                # should not come here
                 pass
 
         c.execute("CREATE IDENT MIMERPY AS USER USING 'PySecret'")
